A data.table with one row per response, i.e., one row per form
submission per field. If necessary to avoid ambiguity, columns from the
"survey" part of the form definition are prefixed with field_, while
columns from the "choices" part of the form definition are prefixed with
choice_. Original column names from data returned by scto_read() are
in the submission_field_name column, while corresponding values are in
the field_value column. Data can be converted back to wide format as
desired using data.table::dcast() or tidyr::pivot_wider().
Arguments
auth
scto_auth() object.
form_id
String indicating id of the form.
id_cols
Character vector of data columns to keep in the result, will
be passed as id.vars to data.table::melt().
exclude_cols
Character vector of data columns to exclude from the
result.