data_old: A data.table of the previous version of the dataset.
response: An object of class httr::response() from the POST request.
Arguments
auth
scto_auth() object.
data
data.frame to upload.
dataset_id
String indicating id of existing dataset.
dataset_title
String indicating title of dataset. Will replace the
existing title, regardless of append.
append
Logical indicating whether to append or replace the dataset.
fill
Logical indicating whether to implicitly fill missing columns
with NA, i.e., whether to allow a mismatch between columns of the
existing dataset and columns of data. Only used if append is TRUE.